﻿function NewTemplate() {
	EditTemplate({ TemplateId: 0, Name: "", Body: "", CategoryIDs: [] });
}

function EditTemplate(templateObj) {
	getCategoriesList(function () {
		cannedRespVue.EditedTemplate = null; //to force edit-form redraw, cause we're not using "v-model" reactivity on it
		cannedRespVue.EditedTemplate = templateObj;
		$("#templateCategoryId").val(templateObj.CategoryIDs); //jquery multiselect doesn't work with Vue's reactivity
		cannedRespVue.UneditedTemplate = Object.assign({}, templateObj); //backup object to prevent reactivity on "cancel"
		Vue.nextTick(function () { $("#templateCategoryId").multiselect("refresh"); }); //refresh multiselect only after Vue updates
	});

	$("#templateEdit").modal();
}

function loadCannedResps() {
	var categoryId = 0;
	if (HDApp.CategoryId) { //are we called from ticket form? or admin page?
		categoryId = HDApp.CategoryId;
	}
	var elem = $("#selTemplates");
	if (elem.data("loaded") == false) {
		$.ajax({
			url: globalRootAppUrl + "Ticket/GetTemplates?categoryId=" + categoryId,
			cache: false,
			success: function (data) {
				cannedRespVue.Templates = data.Templates;
				data.Groups.push({ GroupID: null, Name: '', shown: true }); //add "empty" group for elements without group
				cannedRespVue.Groups = data.Groups;
				cannedRespVue.$nextTick(function () {
					$('#cannedFilter').focus(); //refocus
				});
			}
		});
		elem.data("loaded", true);
	}
}

function SaveTemplate() {
	$.ajaxSetup({ traditional: true }); //to prevent adding "[]" to post names

	if (!cannedRespVue.EditedTemplate.Name || !cannedRespVue.EditedTemplate.Body) return;

	cannedRespVue.EditedTemplate.CategoryIDs = $("#templateCategoryId").val() || []; //jquery multiselect breaks reactivity

	var newGroupName = cannedRespVue.$refs["newTemplateGroup"].value;
	var creatingNewGroup = (cannedRespVue.EditedTemplate.GroupID == 'new' && newGroupName)

	if (cannedRespVue.EditedTemplate.TemplateId) {
		//edit
		$.post(globalRootAppUrl + "Ticket/SaveTemplate", { name: encodeURIComponent(cannedRespVue.EditedTemplate.Name), body: encodeURIComponent(cannedRespVue.EditedTemplate.Body), id: cannedRespVue.EditedTemplate.TemplateId, categoryId: cannedRespVue.EditedTemplate.CategoryIDs, groupId: cannedRespVue.EditedTemplate.GroupID, newTemplateGroup: newGroupName }, function (data) {
			cannedRespVue.EditedTemplate.GroupID = data.groupId;
			if (creatingNewGroup)
				cannedRespVue.Groups.unshift({ GroupID: data.groupId, Name: newGroupName });
			$.modal.close();
		});
	} else {
		//new
		$.post(globalRootAppUrl + "Ticket/SaveTemplate", { name: encodeURIComponent(cannedRespVue.EditedTemplate.Name), body: encodeURIComponent(cannedRespVue.EditedTemplate.Body), categoryId: cannedRespVue.EditedTemplate.CategoryIDs, groupId: cannedRespVue.EditedTemplate.GroupID, newTemplateGroup: newGroupName }, function (data) {
			cannedRespVue.EditedTemplate.GroupID = data.groupId;
			cannedRespVue.EditedTemplate.TemplateId = data.id;
			cannedRespVue.Templates.push(cannedRespVue.EditedTemplate);
			if (creatingNewGroup)
				cannedRespVue.Groups.unshift({ GroupID: data.groupId, Name: newGroupName });
			$.modal.close();
		});
	}
}

function ProcessTemplate(templateObj) {
	if (!window.wswgEditor) {
		//we're in the admin area not in ticket
		EditTemplate(templateObj);
		return;
	}
	InsertTemplate(templateObj.Body);
}

function InsertTemplate(body) {
	var txt = body;
	txt = txt.replace("#FirstName#", $('#lnkFrom').data("firstname"));
	txt = txt.replace("#LastName#", $('#lnkFrom').data("lastname"));
	txt = txt.replace("#Technician#", $('#lnkAssignedTo').text());
	if (wswgEditor.IsEditorVisible()) {
		txt = txt.replace(/<br[^>]*>\n/gi, "<br>"); //to prevent double-break if there's already <br>\n
		txt = txt.replace(/\n/gi, "<br />");
	}
	wswgEditor.InsertText(txt);
}

function InsertTemplateExternal(templateId) {
	var template = cannedRespVue.Templates.filter(function (t) { return t.TemplateId == templateId });
	if (template.length) {
		InsertTemplate(template[0].Body);
	}
}

function DeleteTemplate(templateObj) {
	if (!confirm(_langStrings.AreYouSure)) return;
	cannedRespVue.Templates = cannedRespVue.Templates.filter(function (item) { return item !== templateObj; }); //remove from list
	$.modal.close();
	$.post(globalRootAppUrl + "Ticket/DeleteTemplate", { templateId: templateObj.TemplateId });
}

function getCategoriesList(callback) {
	callback = callback || $.noop;
	if ($("#templateCategoryId option").length) { //already loaded
		callback();
		return;
	}
	$.post(globalRootAppUrl + "Ticket/GetCategoriesHtmlSelect", function (data) {
		$('#templateCategoryId').html(data).attr("multiple", "");
		$("#templateCategoryId").val([]);
		$("#templateCategoryId").multiselect({ noneSelectedText: 'ALL', selectedText: "# of # selected" });
		callback();
	});
}

$(function () {
	window.cannedRespVue = Vue.createApp({
		data() { return { Templates: [], Groups: [], EditedTemplate: {}, UneditedTemplate: {}, quickSearchStr: "" } },
		computed: {
			filteredGroups: function () {
				return this.Groups.filter(function (grp) {
					var lcSearch = cannedRespVue.quickSearchStr.toLowerCase(); //quicksearch filter
					grp.Templates = cannedRespVue.Templates.filter(function (tpl) { //assign templates to this group (filtering them first)
						return tpl.GroupID == grp.GroupID && (!lcSearch.length || (tpl.Name.toLowerCase().indexOf(lcSearch) > -1 || tpl.Body.toLowerCase().indexOf(lcSearch) > -1));
					});

					if (grp.Templates.length > 0 && cannedRespVue.quickSearchStr.length > 0)
						grp['shown'] = true;
					
					return grp.Templates.length;
				});
			},
			orderedGroups: function () { //used for dropdown in editor
				return this.Groups.concat().sort(function (g1, g2) { return g1.Name.localeCompare(g2.Name); }); //concat to copy array
			}
		},
		methods: {
			Cancel: function () {
				$.modal.close();
				Object.assign(this.EditedTemplate, this.UneditedTemplate); //restore unedited from backup
			},
			toggleShown: function (grp) {
				grp.shown = !grp.shown;
			},
			onPaste: function (evt) {
				for (var i = 0; i < evt.clipboardData.items.length; i++) { //find image in clipboard
					var item = evt.clipboardData.items[i];
					if (item.kind == "file" && item.type.startsWith("image/")) {
						var imageFile = item.getAsFile();
						var fileReader = new FileReader();
						fileReader.onloadend = function () {
							cannedRespVue.EditedTemplate.Body += " <img src='" + fileReader.result + "'>";
						}
						fileReader.readAsDataURL(imageFile);
						break;
					}
				}
			},
			ProcessTemplate: function (t) { ProcessTemplate(t); }, //stub because window context not available to Vue's inline JS
			EditTemplate: function (t) { EditTemplate(t); },
			DeleteTemplate: function (t) { DeleteTemplate(t); },
		}
	}).mount("#selTemplates");

	$("#selTemplates").on("dropdown:show", function () {
		$('#cannedFilter').focus();
	});
});

// called from viewticket.js
function openCannedRespDropdownExternal() {
	loadCannedResps();
	$("#selTemplates").addClass('open');
	$('#cannedFilter').focus();
}