CREATE table #Issues(IssueID INT PRIMARY key)

insert into #Issues --issues to be transfered
select IssueID FROM hdIssues WITH(NOLOCK) where InstanceID=@InstanceID

PRINT 'Comments'
--batch-insert in chunks
SET IDENTITY_INSERT #DBName#.dbo.hdComments ON
declare @startid int = 0
WHILE 1 = 1
BEGIN
	INSERT INTO #DBName#.dbo.hdComments WITH (TABLOCK) ([CommentID], [IssueID],  [CommentDate] , [UserID], [Body] ,  [ForTechsOnly], [IsSystem] , Recipients ,  EmailHeaders, BouncedRecipients, BounceReason, InstanceID)
	SELECT [CommentID], [IssueID],  [CommentDate] , [UserID], [Body] ,  [ForTechsOnly], [IsSystem] , Recipients ,  EmailHeaders, BouncedRecipients, BounceReason, InstanceID
	FROM hdComments WITH(NOLOCK) WHERE IssueID IN (select TOP 200 IssueID FROM #Issues WHERE IssueID>@startid ORDER BY IssueID) --next 200 tickets
	option(MAXDOP 4);

	with top200 (IssueID) as (select top 200 IssueID from #Issues WHERE IssueID>@startid ORDER BY IssueID)
	select @startid=max(IssueID) from top200;

	IF (@startid is null) BREAK; -- no more tickets
	
	WAITFOR DELAY '00:00:00.500'
END
SET IDENTITY_INSERT #DBName#.dbo.hdComments OFF
--end batch-insert

PRINT 'Companies'
SET IDENTITY_INSERT #DBName#.dbo.hdCompanies ON
INSERT INTO #DBName#.dbo.hdCompanies (CompanyID, InstanceID, [Name],Notes)
SELECT CompanyID, 0 as InstanceID, [Name], Notes FROM hdCompanies where InstanceID=@InstanceID
SET IDENTITY_INSERT #DBName#.dbo.hdCompanies OFF

PRINT 'Company domains'
INSERT INTO #DBName#.dbo.CompanyDomains (CompanyID, Domain)
SELECT CompanyID, Domain FROM CompanyDomains where CompanyID IN (SELECT CompanyID FROM hdCompanies WHERE InstanceID=@InstanceID)

PRINT 'Departments'
SET IDENTITY_INSERT #DBName#.dbo.Departments ON
INSERT INTO #DBName#.dbo.Departments (DepartmentID, InstanceID,  [Name])
SELECT DepartmentID, 0 as InstanceID,  [Name] FROM Departments where InstanceID=@InstanceID
SET IDENTITY_INSERT #DBName#.dbo.Departments OFF

PRINT 'Categories'
SET IDENTITY_INSERT #DBName#.dbo.hdCategories ON
INSERT INTO #DBName#.dbo.hdCategories ([CategoryID],[Name],[SectionID],[InstanceID],[ForTechsOnly],ForSpecificUsers,OrderByNumber,FromAddress,KBOnly,FromName,Disabled, Notes)
SELECT [CategoryID],[Name],[SectionID], 0 as InstanceID,[ForTechsOnly],ForSpecificUsers,OrderByNumber,FromAddress,KBOnly,FromName,Disabled, Notes FROM hdCategories where InstanceID=@InstanceID
update #DBName#.dbo.hdCategories set instanceid=0
SET IDENTITY_INSERT #DBName#.dbo.hdCategories OFF

PRINT 'Issues'
--batch-insert in chunks of 2000
SET IDENTITY_INSERT #DBName#.dbo.hdIssues ON
declare @startIssueId int = 0
while 1=1
begin
	INSERT INTO #DBName#.dbo.hdIssues (IssueID,InstanceID,IssueDate,UserID,CategoryID,ResolvedDate,AssignedToUserID,Subject,Body,UpdatedByUser,UpdatedByPerformer,StatusID,Priority,StartDate,LastUpdated,DueDate,TimeSpentInSeconds,UpdatedForTechView, Origin, TimesReopened, Rating, LastUpdatedByUserID)
	SELECT top 1000 IssueID,0 as InstanceID,IssueDate,UserID,CategoryID,ResolvedDate,AssignedToUserID,Subject,Body,UpdatedByUser,UpdatedByPerformer,StatusID,Priority,StartDate,LastUpdated,DueDate,TimeSpentInSeconds,UpdatedForTechView, Origin, TimesReopened, Rating, LastUpdatedByUserID
	FROM hdIssues WITH(NOLOCK) WHERE InstanceID=@InstanceID
	AND IssueID > @startIssueId
	ORDER BY IssueID ASC
	option(MAXDOP 4)

	IF (@@ROWCOUNT = 0) BREAK;

	SELECT @startIssueId = MAX(IssueID) FROM #DBName#.dbo.hdIssues
	
	WAITFOR DELAY '00:00:02'
end
SET IDENTITY_INSERT #DBName#.dbo.hdIssues OFF
--end batch-insert

PRINT 'Comment Templates'
SET IDENTITY_INSERT #DBName#.dbo.hdCommentTemplates ON
INSERT INTO #DBName#.dbo.hdCommentTemplates ([TemplateID],[InstanceID],[Body],[Name], GroupID)
SELECT [TemplateID],0 as [InstanceID],[Body],[Name],GroupID FROM hdCommentTemplates WHERE InstanceID=@InstanceID
SET IDENTITY_INSERT #DBName#.dbo.hdCommentTemplates OFF

SET IDENTITY_INSERT #DBName#.dbo.CommentTemplateGroups ON
INSERT INTO #DBName#.dbo.CommentTemplateGroups (GroupID,[InstanceID],[Name])
SELECT GroupID,0 as [InstanceID],[Name] FROM CommentTemplateGroups WHERE InstanceID=@InstanceID
SET IDENTITY_INSERT #DBName#.dbo.CommentTemplateGroups OFF

PRINT 'CommentTemplateCategories'
INSERT INTO #DBName#.dbo.CommentTemplateCategories SELECT * FROM CommentTemplateCategories WHERE CategoryID in (select CategoryID FROM hdCategories WHERE InstanceID=@InstanceID)

PRINT 'File attachments'
SET IDENTITY_INSERT #DBName#.dbo.hdFileAttachments ON
INSERT INTO #DBName#.dbo.hdFileAttachments([FileID],[IssueID],[UserID],[FileName],[FileData], CommentID, FileHash, FileSize, HiddenFromKB, HiddenFromTickets, AssetID)
SELECT [FileID],[IssueID],[UserID],[FileName],[FileData],CommentID,FileHash,FileSize,HiddenFromKB,HiddenFromTickets, AssetID
FROM hdFileAttachments WITH(NOLOCK) WHERE IssueID in (select IssueID FROM #Issues)
SET IDENTITY_INSERT #DBName#.dbo.hdFileAttachments OFF

PRINT 'Issue subs'
INSERT INTO #DBName#.dbo.hdIssueSubscribers SELECT * FROM hdIssueSubscribers WHERE IssueID in (select IssueID FROM #Issues)

PRINT 'Secondary assignees'
INSERT INTO #DBName#.dbo.SecondaryAssignees SELECT * FROM SecondaryAssignees WHERE IssueID in (select IssueID FROM #Issues)

WAITFOR DELAY '00:00:02'

PRINT 'CF vals'
INSERT INTO #DBName#.dbo.hdCustomFieldValues SELECT * FROM hdCustomFieldValues WHERE IssueID in (select IssueID FROM #Issues)

PRINT 'CF vals assets'
INSERT INTO #DBName#.dbo.hdCustomFieldValuesForAssets SELECT * FROM hdCustomFieldValuesForAssets WHERE ItemID in (select ItemID FROM hdAssets where InstanceID=@InstanceID)

PRINT 'CF vals users'
INSERT INTO #DBName#.dbo.hdCustomFieldValuesForUsers SELECT * FROM hdCustomFieldValuesForUsers WHERE FieldID in (select FieldID FROM hdCustomFields where InstanceID=@InstanceID)

PRINT 'CF vals companies'
INSERT INTO #DBName#.dbo.hdCustomFieldValuesForCompanies SELECT * FROM hdCustomFieldValuesForCompanies WHERE FieldID in (select FieldID FROM hdCustomFields where InstanceID=@InstanceID)

WAITFOR DELAY '00:00:02'
PRINT 'Issue schedule'
INSERT INTO #DBName#.dbo.hdIssueSchedule ([IssueID],[FreqType],[FirstRecurrenceDate],[PrevRepeatsCount],ReopenOriginal,LastRecurrenceDate)
SELECT [IssueID],[FreqType],[FirstRecurrenceDate],[PrevRepeatsCount],ReopenOriginal,LastRecurrenceDate FROM hdIssueSchedule WHERE IssueID in (select IssueID FROM #Issues)

PRINT 'KB articles'
INSERT INTO #DBName#.dbo.KBArticles ([ArticleID],[InstanceID],[CategoryID],[Subject],[Body] ,[ForTechsOnly],OrderByNumber,DateCreated,LastUpdated,AIMeta,CreatedByUserID,LastUpdatedByUserID)
SELECT [ArticleID], 0 as InstanceID,[CategoryID],[Subject],[Body] ,[ForTechsOnly],OrderByNumber,DateCreated,LastUpdated,AIMeta,CreatedByUserID,LastUpdatedByUserID FROM KBArticles WHERE InstanceID=@InstanceID

PRINT 'KB subs'
INSERT INTO #DBName#.dbo.KBSubscribers(CategoryID,UserID)
SELECT CategoryID,UserID FROM KBSubscribers where CategoryID in (select CategoryID FROM hdCategories WHERE InstanceID=@InstanceID)

PRINT 'KB article subs'
INSERT INTO #DBName#.dbo.KBArticleSubscribers(ArticleID,UserID)
SELECT ArticleID,UserID FROM KBArticleSubscribers where ArticleID in (select ArticleID FROM KBArticles WHERE InstanceID=@InstanceID)

PRINT 'KB cache'
INSERT INTO #DBName#.dbo.KBSuggestionsCache(IssueID,ArticleID)
SELECT IssueID,ArticleID FROM KBSuggestionsCache where IssueID in (select IssueID FROM #Issues)

PRINT 'KB view log'
INSERT INTO #DBName#.dbo.KBViewLog(ArticleID,Date,NumViews)
SELECT ArticleID,Date,NumViews FROM KBViewLog where ArticleID in (select ArticleID FROM KBArticles WHERE InstanceID=@InstanceID)

PRINT 'KB Search log'
SET IDENTITY_INSERT #DBName#.dbo.KBSearchLog ON
INSERT INTO #DBName#.dbo.KBSearchLog(SearchID,InstanceID,Date,Query,NumResults)
SELECT SearchID,0 as InstanceID,Date,Query,NumResults FROM KBSearchLog WHERE InstanceID=@InstanceID
SET IDENTITY_INSERT #DBName#.dbo.KBSearchLog OFF


PRINT 'linked issues'
INSERT INTO #DBName#.dbo.hdLinkedIssues(Issue1ID,Issue2ID)
SELECT Issue1ID,Issue2ID FROM hdLinkedIssues where Issue1ID in (select IssueID FROM #Issues)

PRINT 'Sub issues'
INSERT INTO #DBName#.dbo.hdSubIssues(ParentID,ChildID)
SELECT ParentID,ChildID FROM hdSubIssues where ParentID in (select IssueID FROM #Issues)

PRINT 'merged issues'
INSERT INTO #DBName#.dbo.hdMergedIssues(IssueID,IssueMergedID)
SELECT IssueID,IssueMergedID FROM hdMergedIssues where IssueID in (select IssueID FROM #Issues)

PRINT 'scheduled issues'
INSERT INTO #DBName#.dbo.hdScheduledIssues(ScheduledIssueID,OriginalIssueID)
SELECT ScheduledIssueID,OriginalIssueID FROM hdScheduledIssues where OriginalIssueID in (select IssueID FROM #Issues)

PRINT 'ass man'
SET IDENTITY_INSERT #DBName#.dbo.hdAssetManufacturers ON
INSERT INTO #DBName#.dbo.hdAssetManufacturers(ManufacturerID,InstanceID,[Name])
SELECT ManufacturerID,0 as InstanceID,[Name] FROM hdAssetManufacturers where InstanceID=@InstanceID
SET IDENTITY_INSERT #DBName#.dbo.hdAssetManufacturers OFF

PRINT 'ass'
SET IDENTITY_INSERT #DBName#.dbo.hdAssets ON
INSERT INTO #DBName#.dbo.hdAssets (ItemID,InstanceID,ModelName,TypeID,ManufacturerID,Quantity,SupplierID,SerialNumber,Location,Comments,CompanyID,Disabled)
SELECT ItemID,0 as InstanceID,ModelName,TypeID,ManufacturerID,Quantity,SupplierID,SerialNumber,Location,Comments,CompanyID,Disabled FROM hdAssets where InstanceID=@InstanceID
SET IDENTITY_INSERT #DBName#.dbo.hdAssets OFF

PRINT 'ass sup'
SET IDENTITY_INSERT #DBName#.dbo.hdAssetSuppliers ON
INSERT INTO #DBName#.dbo.hdAssetSuppliers(SupplierID,InstanceID,[Name])
SELECT SupplierID,0 as InstanceID,[Name] FROM hdAssetSuppliers where InstanceID=@InstanceID
SET IDENTITY_INSERT #DBName#.dbo.hdAssetSuppliers OFF


PRINT 'ass type'
SET IDENTITY_INSERT #DBName#.dbo.hdAssetTypes ON
INSERT INTO #DBName#.dbo.hdAssetTypes(TypeID,InstanceID,[Name])
SELECT TypeID,0 as InstanceID,[Name] FROM hdAssetTypes where InstanceID=@InstanceID
SET IDENTITY_INSERT #DBName#.dbo.hdAssetTypes OFF

PRINT 'tag'
SET IDENTITY_INSERT #DBName#.dbo.hdTags ON
INSERT INTO #DBName#.dbo.hdTags(TagID,[Name],InstanceID)
SELECT TagID,[Name],0 FROM hdTags where InstanceID=@InstanceID
SET IDENTITY_INSERT #DBName#.dbo.hdTags OFF

PRINT 'OT Checks'
INSERT INTO #DBName#.dbo.OneTimeChecks(CheckID)
SELECT * FROM OneTimeChecks

WAITFOR DELAY '00:00:02'

PRINT 'Issue tags'
INSERT INTO #DBName#.dbo.hdIssueTags SELECT * FROM hdIssueTags where IssueID in (SELECT IssueID FROM #Issues)
PRINT 'Asset users'
INSERT INTO #DBName#.dbo.hdAssetUsers SELECT * FROM hdAssetUsers where UserID in (SELECT UserID FROM hdUsers where InstanceID=@InstanceID)
PRINT 'Asset issues'
INSERT INTO #DBName#.dbo.hdAssetsIssues SELECT * FROM hdAssetsIssues where IssueID in (SELECT IssueID FROM #Issues)
PRINT 'SecondaryEmails'
INSERT INTO #DBName#.dbo.SecondaryEmails SELECT UserID, Email FROM SecondaryEmails WHERE UserID in (SELECT UserID FROM hdUsers where InstanceID=@InstanceID)

WAITFOR DELAY '00:00:02'
PRINT 'On behalf'
INSERT INTO #DBName#.dbo.hdOnBehalfIssues SELECT * FROM hdOnBehalfIssues where IssueID in (SELECT IssueID FROM #Issues)
PRINT 'cat perm'
INSERT INTO #DBName#.dbo.hdCategoryPermissions SELECT * FROM hdCategoryPermissions where CategoryID IN (select CategoryID FROM hdCategories where InstanceID=@InstanceID)
PRINT 'ticket templ'
INSERT INTO #DBName#.dbo.TicketTemplates SELECT * FROM TicketTemplates where CategoryID IN (select CategoryID FROM hdCategories where InstanceID=@InstanceID)
PRINT 'cat subm perm'
INSERT INTO #DBName#.dbo.hdCategorySubmitPermissions SELECT * FROM hdCategorySubmitPermissions where CategoryID IN (select CategoryID FROM hdCategories where InstanceID=@InstanceID)

WAITFOR DELAY '00:00:02'
PRINT 'cat field cat'
INSERT INTO #DBName#.dbo.CustomFieldCategories SELECT * FROM CustomFieldCategories where CategoryID IN (select CategoryID FROM hdCategories where InstanceID=@InstanceID)
PRINT 'cf options'
SET IDENTITY_INSERT #DBName#.dbo.hdCustomFieldOptions ON
INSERT INTO #DBName#.dbo.hdCustomFieldOptions ([OptionID],[FieldID],[OptionValue],IsDefault,OrderByNumber,IsDisabled,ParentOptionID)
SELECT [OptionID],[FieldID],[OptionValue],IsDefault,OrderByNumber,IsDisabled,ParentOptionID FROM hdCustomFieldOptions WHERE FieldID IN (SELECT FieldID FROM hdCustomFields where InstanceID=@InstanceID)
SET IDENTITY_INSERT #DBName#.dbo.hdCustomFieldOptions OFF
PRINT 'cf'
SET IDENTITY_INSERT #DBName#.dbo.hdCustomFields ON
INSERT INTO #DBName#.dbo.hdCustomFields([FieldID],[InstanceID],[Type],[FieldName],[Mandatory],[OrderByNumber], ShowInGrid, UsageType,AccessType,ParentFieldID)
SELECT [FieldID],0 as [InstanceID],[Type],[FieldName],[Mandatory],[OrderByNumber], ShowInGrid, UsageType,AccessType,ParentFieldID FROM hdCustomFields where InstanceID=@InstanceID
SET IDENTITY_INSERT #DBName#.dbo.hdCustomFields OFF

WAITFOR DELAY '00:00:02'
PRINT 'users'
SET IDENTITY_INSERT #DBName#.dbo.hdUsers ON
INSERT INTO #DBName#.dbo.hdUsers ([UserID],[InstanceID],[UserName],[Email],[Password],[IsAdministrator],[FirstName] ,[LastName],CompanyID,[Notes],[Phone],[Location],[SendEmail],Disabled,LastSeen,IPAddress,HostName,Lang,UserAgent,[Signature],Greeting,DepartmentID,IsManager,IsDepartmentManager,PushToken,TechTutorialShown,AdminTutorialShown,TwoFactorAuthEnabled, TimezoneID, SendNewTicketTechEmail, OutOfOffice, LastLogoutDate, DateCreated)
SELECT [UserID], 0 as [InstanceID],[UserName],[Email],[Password],[IsAdministrator],[FirstName] ,[LastName],CompanyID,[Notes],[Phone],[Location],[SendEmail],Disabled,LastSeen,IPAddress,HostName,Lang,UserAgent,[Signature],Greeting,DepartmentID,IsManager,IsDepartmentManager,PushToken,TechTutorialShown,AdminTutorialShown,TwoFactorAuthEnabled, TimezoneID, SendNewTicketTechEmail, OutOfOffice, LastLogoutDate, DateCreated FROM hdUsers where InstanceID=@InstanceID
update  #DBName#.dbo.hdUsers set instanceid=0
SET IDENTITY_INSERT #DBName#.dbo.hdUsers OFF

WAITFOR DELAY '00:00:02'
PRINT 'sections'
SET IDENTITY_INSERT #DBName#.dbo.hdSections ON
INSERT INTO #DBName#.dbo.hdSections([SectionID],[Name],[InstanceID],OrderByNumber)
SELECT [SectionID],[Name],0 as [InstanceID],OrderByNumber FROM hdSections where InstanceID=@InstanceID
SET IDENTITY_INSERT #DBName#.dbo.hdSections OFF
PRINT 'status'
SET IDENTITY_INSERT #DBName#.dbo.hdStatus ON
INSERT INTO #DBName#.dbo.hdStatus([StatusID],InstanceID,[Name],[ButtonCaption],AccessType, StopTimeSpent, Color, OrderByNumber)
SELECT [StatusID],0 as InstanceID,[Name],[ButtonCaption],AccessType, StopTimeSpent, Color, OrderByNumber FROM hdStatus where InstanceID=@InstanceID
SET IDENTITY_INSERT #DBName#.dbo.hdStatus OFF
PRINT 'priorities'
SET IDENTITY_INSERT #DBName#.dbo.Priorities ON
INSERT INTO #DBName#.dbo.Priorities([PriorityID],InstanceID,[Name])
SELECT [PriorityID],0 as InstanceID,[Name] FROM Priorities where InstanceID=@InstanceID
SET IDENTITY_INSERT #DBName#.dbo.Priorities OFF
PRINT 'pop servers'
SET IDENTITY_INSERT #DBName#.dbo.hdPOPServers ON
INSERT INTO #DBName#.dbo.hdPOPServers(ServerID,[InstanceID],HostName,POPLogin,POPPassword,Port,UseSSL,NewTicketsCategoryID,[Disabled],ImapMarkSeenNotDelete, Protocol, EwsImpersonatedUserEmail, LastConnectResult)
SELECT ServerID,0 as [InstanceID],HostName,POPLogin,POPPassword,Port,UseSSL,NewTicketsCategoryID,[Disabled],ImapMarkSeenNotDelete, Protocol, EwsImpersonatedUserEmail, LastConnectResult FROM hdPOPServers where InstanceID=@InstanceID
SET IDENTITY_INSERT #DBName#.dbo.hdPOPServers OFF
PRINT 'report sch'
INSERT INTO #DBName#.dbo.ReportSchedule SELECT * FROM ReportSchedule where InstanceID=@InstanceID
update #DBName#.dbo.ReportSchedule SET InstanceID=0
PRINT 'settings'
INSERT INTO #DBName#.dbo.hdSettings (InstanceID,EmailNotificationsEnabled,SMTPServer,SMTPAuthRequired,SMTPUserName,SMTPPassword,SMTPUseSSL,FromAddress,AllowUserRegistration,SMTPPort,MailCheckerNewIssuesCategoryID,MailCheckerAllowUnregisteredUsers,RestrictIssueDeletion,Lang,RestrictIssueClosing,NewIssuesDefaultCategoryID,AllowGuestSubmission,AllowAnonymousKBAccess,SeeEveryonesIssues,UseDefaultSmtp,HeaderBGColor,MenuBarBGColor,LogoImage,SendTechniciansEmailOnNewIssue,ReplyToAddress,FromName,DisableKB,AutoLoginSharedSecret,MenuBarTextColor,DisableCloseNotification,Title,DisableAssets,DaysToCloseAfter,UseFromNameForUserOriginatedMsgs,HeaderTextColor,SameCompanyUserPermission,HidePoweredBy,DisableAvatars,SendAdminEmailOnNewIssue,AutoAssignFirstReplier,NotifyAllTechsOnReply,NewTicketNote,CustomCSS,DisableAutoTimer,DontAddCCToSubscribers,WorkHourFrom,WorkHourTo,EmailOtherTechsOnTakeover,EnableSaml,SamlEndpoint,SamlCertificate,DisableTicketConfirmationNotification,TimezoneID,ActiveTabTextColor,RemoteLoginURL,NoAttachmentsInNotifications,DisableAutologinLinks,ExtractOriginalSenderFromFwd, FaviconImage, EnableGoogleLogin, DisableUsernameEmailEdit, KBTitle, KBCss, KBHeadCode, SendTechEmailOnKBUpdate, HideLoginButtonWhenSAML, CustomJS, EnableMultiAsssign, LogoUrl, DaysToAllowReopen, SamlEntityId, KBBotEnabled, KBHomeArticleCount, DisableIdeas, MailcheckerUnregDomains, GoogleLoginDomains, ExtractCompaniesFromDomains, ExtractCompaniesExceptions, RestrictPriority, IdeasName, TopAnnouncementHTML, MailcheckerRestrictedDomains, CcForOutgoingEmails, TicketMinChars, SamlButtonText, TopTechAnnouncementHTML, TopAdminAnnouncementHTML, SamlAutoRedirect, ReportPermissionsJson, DisableRememberMe, RestrictAdminAssignment, DisableDefaultHolidays, SameDepartmentUserPermission,DaysToDeleteAfter,TechOnlyEmailReplies,HideSystemComments,ThankYouText,SMTPOAuthToken, SMTPOAuthRefreshToken, RequireMFA, UselessFilterWhitelist, AppURL, EmailOnTakeoverIncludeAdmins, Office365GccClientId, Office365GccClientSecret, DisableAutoTimerPause, AutoTimerOnlyWhenAssigned, AllowFreeEmails, NewTicketLayout, RestrictAssetsToAdmins, IPRestrictions)
SELECT * FROM hdSettings where InstanceID=@InstanceID
update #DBName#.dbo.hdSettings SET InstanceID=0
PRINT 'integr'
INSERT INTO #DBName#.dbo.Integrations ([InstanceID], BitbucketEnabled, BitbucketUsername, BitbucketPassword, HipChatEnabled, HipChatAuthToken, HipChatRoomId, JiraEnabled, JiraUsername, JiraPassword, JiraUrl, DropboxEnabled, DropboxAppID, SlackEnabled, SlackWebhookURL, GitHubEnabled,	GitHubUsername,	GitHubPassword, UserLookupEnabled, UserLookupURL, AsanaEnabled, AsanaAccessToken, TrelloEnabled, VSOEnabled, VSOAccountName, VSOUsername, VSOToken, HarvestEnabled, HarvestUsername, HarvestPassword, HarvestAccount, ZapierEnabled, UserLookupBasicAuthEnabled, UserLookupUsername, UserLookupPassword, GoogleDriveEnabled,  GithubEnterpriseUrl, HighriseEnabled, HighriseUrl, HighriseToken, VSOSelfHosted, GitLabEnabled, GitLabToken, VSOCollectionName, StripeEnabled, SurveyMonkeyEnabled, SurveyMonkeyToken, GitHubToken, StripeToken, BasecampEnabled, BasecampToken, BasecampAccID, MsTeamsEnabled, MsTeamsWebhookUrl, GitLabBaseUrl, OneDriveEnabled, BoxEnabled, AsanaRefreshToken, TeamViewerEnabled, TeamViewerFieldID, ClickUpEnabled, ClieckUpToken, WhatsAppEnabled, WhatsAppPhoneNumberId, WhatsAppToken, SnipeItEnabled, SnipeItUrl, SnipeItToken, GPTEnabled, GPTApiKey, GPTIncludeKB, LansweeperEnabled, LansweeperToken, LansweeperSiteId)
SELECT * FROM Integrations where InstanceID=@InstanceID
update #DBName#.dbo.Integrations SET InstanceID=0
PRINT 'integr ticket data'
INSERT INTO #DBName#.dbo.IntegrationTicketData (IssueID, BitbucketIssueUrl, JiraIssueUrl, GitHubIssueUrl, AsanaTaskUrl, TrelloCardUrl, VSOWorkItemUrl, HarvestProjectUrl, GitLabIssueUrl, BasecampTodoUrl, ClickUpTaskUrl, SnipeItIds, LansweeperIds)
SELECT * FROM IntegrationTicketData WHERE IssueID IN (select IssueID FROM #Issues)
PRINT 'email tmpl'
INSERT INTO #DBName#.dbo.EmailTemplates SELECT * FROM EmailTemplates where InstanceID=@InstanceID
update #DBName#.dbo.EmailTemplates SET InstanceID=0
PRINT 'psw pol'
INSERT INTO #DBName#.dbo.PasswordPolicies SELECT * FROM PasswordPolicies where InstanceID=@InstanceID
PRINT 'rules'
SET IDENTITY_INSERT #DBName#.dbo.AutomationRules ON
INSERT INTO #DBName#.dbo.AutomationRules(RuleID, InstanceID,RuleXml, OrderByNumber)
SELECT * FROM AutomationRules where InstanceID=@InstanceID
update  #DBName#.dbo.AutomationRules set instanceid=0
SET IDENTITY_INSERT #DBName#.dbo.AutomationRules OFF

INSERT INTO #DBName#.dbo.hdUserLogonHistory(UserID, LogonDate,IPAddress)
SELECT * FROM hdUserLogonHistory where UserID in (select UserID from hdUsers where InstanceID = @instanceId)

DROP table #Issues

